==> zio-aws-auditmanager_3-5.17.153.3-sources.jar: zio/aws/auditmanager/model/ListControlDomainInsightsByAssessmentResponse.scala <==
package zio.aws.auditmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.auditmanager.model.primitives.Token
import scala.jdk.CollectionConverters.*
final case class ListControlDomainInsightsByAssessmentResponse(
    controlDomainInsights: Option[
      Iterable[zio.aws.auditmanager.model.ControlDomainInsights]
    ] = None,
    nextToken: Option[Token] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.auditmanager.model.ListControlDomainInsightsByAssessmentResponse = {
    import ListControlDomainInsightsByAssessmentResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.auditmanager.model.ListControlDomainInsightsByAssessmentResponse
      .builder()
      .optionallyWith(
        controlDomainInsights.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.controlDomainInsights)
      .optionallyWith(
        nextToken.map(value => Token.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.auditmanager.model.ListControlDomainInsightsByAssessmentResponse.ReadOnly =
    zio.aws.auditmanager.model.ListControlDomainInsightsByAssessmentResponse
      .wrap(buildAwsValue())
}
object ListControlDomainInsightsByAssessmentResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.auditmanager.model.ListControlDomainInsightsByAssessmentResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.auditmanager.model.ListControlDomainInsightsByAssessmentResponse =
      zio.aws.auditmanager.model.ListControlDomainInsightsByAssessmentResponse(
        controlDomainInsights.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def controlDomainInsights: Option[
      List[zio.aws.auditmanager.model.ControlDomainInsights.ReadOnly]
    ]
    def nextToken: Option[Token]
    def getControlDomainInsights: ZIO[Any, AwsError, List[
      zio.aws.auditmanager.model.ControlDomainInsights.ReadOnly
    ]] =
      AwsError.unwrapOptionField("controlDomainInsights", controlDomainInsights)
    def getNextToken: ZIO[Any, AwsError, Token] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.auditmanager.model.ListControlDomainInsightsByAssessmentResponse
  ) extends zio.aws.auditmanager.model.ListControlDomainInsightsByAssessmentResponse.ReadOnly {
    override val controlDomainInsights: Option[
      List[zio.aws.auditmanager.model.ControlDomainInsights.ReadOnly]
    ] = scala
      .Option(impl.controlDomainInsights())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.auditmanager.model.ControlDomainInsights.wrap(item)
        }.toList
      )
    override val nextToken: Option[Token] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.auditmanager.model.primitives.Token(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.auditmanager.model.ListControlDomainInsightsByAssessmentResponse
  ): zio.aws.auditmanager.model.ListControlDomainInsightsByAssessmentResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-auditmanager_3-5.20.17.1-sources.jar: zio/aws/auditmanager/model/ListControlDomainInsightsByAssessmentResponse.scala <==
package zio.aws.auditmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.auditmanager.model.primitives.Token
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ListControlDomainInsightsByAssessmentResponse(
    controlDomainInsights: Optional[
      Iterable[zio.aws.auditmanager.model.ControlDomainInsights]
    ] = Optional.Absent,
    nextToken: Optional[Token] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.auditmanager.model.ListControlDomainInsightsByAssessmentResponse = {
    import ListControlDomainInsightsByAssessmentResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.auditmanager.model.ListControlDomainInsightsByAssessmentResponse
      .builder()
      .optionallyWith(
        controlDomainInsights.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.controlDomainInsights)
      .optionallyWith(
        nextToken.map(value => Token.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.auditmanager.model.ListControlDomainInsightsByAssessmentResponse.ReadOnly =
    zio.aws.auditmanager.model.ListControlDomainInsightsByAssessmentResponse
      .wrap(buildAwsValue())
}
object ListControlDomainInsightsByAssessmentResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.auditmanager.model.ListControlDomainInsightsByAssessmentResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.auditmanager.model.ListControlDomainInsightsByAssessmentResponse =
      zio.aws.auditmanager.model.ListControlDomainInsightsByAssessmentResponse(
        controlDomainInsights.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def controlDomainInsights: Optional[
      List[zio.aws.auditmanager.model.ControlDomainInsights.ReadOnly]
    ]
    def nextToken: Optional[Token]
    def getControlDomainInsights: ZIO[Any, AwsError, List[
      zio.aws.auditmanager.model.ControlDomainInsights.ReadOnly
    ]] =
      AwsError.unwrapOptionField("controlDomainInsights", controlDomainInsights)
    def getNextToken: ZIO[Any, AwsError, Token] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.auditmanager.model.ListControlDomainInsightsByAssessmentResponse
  ) extends zio.aws.auditmanager.model.ListControlDomainInsightsByAssessmentResponse.ReadOnly {
    override val controlDomainInsights: Optional[
      List[zio.aws.auditmanager.model.ControlDomainInsights.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.controlDomainInsights())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.auditmanager.model.ControlDomainInsights.wrap(item)
        }.toList
      )
    override val nextToken: Optional[Token] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.auditmanager.model.primitives.Token(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.auditmanager.model.ListControlDomainInsightsByAssessmentResponse
  ): zio.aws.auditmanager.model.ListControlDomainInsightsByAssessmentResponse.ReadOnly =
    new Wrapper(impl)
}
